---
author: jeremy
date: "2018-03-27"
title: Undergraduate Dissertation FAQ
---


One of the joys of my work is to supervise bright and highly motivated undergraduates on a year-long dissertation project. This post will serve as a periodically updated guide to working with me as a supervisor on a UG dissertation at UOB.

Last updated: 18 Sep 2020

Undergraduate Dissertation FAQ

1. When is the thesis due?

You should become very familiar with the handbook for the Dissertation course. It has all the details you need regarding deadlines and can be found in the Dissertation module page on Canvas.

2. How do supervisions work?

We meet once a month, for a total of 7 meetings (the first is for planning and subsequent meetings are to discuss progress). For each of the subsequent six supervisions, I'll expect you to send me some form of written work that we can use as the basis for our discussion *no less than 3 working days in advance of our meeting*. 

I prefer to schedule out the whole year's worth of meetings in advance so we can both plan towards these deadlines as writing milestones. You should also bear in mind that supervisors are not allowed to review written work in the final month of your dissertation period, though in light of what I note below, this shouldn't be an issue as hopefully by this time you'll be an independent writer!

3. What kind of supervisor am I?

Of all the work you'll complete during your degree programme, the dissertation is the piece of work which you have the most ownership over. On the basis of this, I approach supervisions as a kind of coaching - I will be ready to answer any questions you have that have arisen during your research and writing, whether about writing mechanics, the research process, or about your topic more specifically. I will also raise probing questions for you, drawing on examples from written work I have been able to review in order to highlight problems or issues more broadly for you as a writer. I will not provide a proofreading service (you should recruit a good friend or two to help with this), so you should always bear in mind that mark-up and feedback is not comprehensive, but suggestive. I'll usually mark the first few instances of an issue in the writing, leaving you to examine the remainder for repeated instances. So you shouldn't expect that anything I *haven't* highlighted or added remarks to on one of your drafts is perfect and shouldn't be revised. I expect you to take notes from our discussions and then review your work to find all the areas where my feedback may be relevant.

4. How do I format my bibliography? Citations? Title Page? Table of contents...

We have a flexible policy regarding citation style, so it's up to you to choose the one that you are most familiar with and then apply that style consistently throughout your dissertation. Please note - I will not serve as a reference for specific aspects of formatting. This is one of the aspects of independent research you should master early on in your research journey (if you haven't already). Each major referencing style has a style guide which covers all the intricacies of formatting as well as other aspects including table of contents formatting, headings, and really anything you could possibly imagine. Given how frequently you may have questions about this, you should purchase a paperback copy of the style guide which will tell you how to format references, number pages, write a table of contents etc. If you don't already have a preference, I'd suggest you go with Chicago Style (a.k.a. Turabian) as it is generally favoured by Theology, Religious Studies, History, and Philosophy. Chicago has both short and long form versions. As above, you can pick one, but if it's up to me, I'd prefer the notes and bibliography format, where you provide longer form versions of citations in footnotes and repeat them in your bibliography. There is an online version of this style guide here: [http://www.chicagomanualofstyle.org/home.html]

5. How many books should I read for a dissertation?

There is no straight-forward way to answer this question, as every dissertation question is quite unique. I tend to favour a style of research that begins by hoovering up as much information as possible, reading a large pile of scholarly materials very quickly so as to get a sense of the breadth of opinion on your topic. Once you have reached an intuitive point of "saturation," you can circle back around to materials that you know superficially to be seminal or particularly relevant to your research and read them more closely so that you can engage with the author's arguments in your own writing. This style of reading is summarised in a now very old book by Mortimer Adler called "How to Read a Book" (1940, revised edition in 1972), which has been come to be called the [Structure-proposition-evaluation method](https://en.wikipedia.org/wiki/Reading_(process)#Methods_of_reading) of reading. I recommend you read Adler's book (quickly!), but you can also find a quick summary here: (https://fourminutebooks.com/how-to-read-a-book-summary/). PS, don't write in library books. PPS, don't bother with Adler's recommended reading list.

So to circle back around to the original question... some rough unqualified estimates: (1) In the hoovering stage, you shouldn't read fewer than a dozen books and/or 3 dozen journal articles. (2) In the critical reading stage, you can focus in on a half dozen books and a dozen articles. But this is really just a rule of thumb - we'll work out a proper ratio in supervision.

6. Which books / articles should I read for my dissertation?

This completely depends on your project. A good rule of thumb is to do keyword searches using terms or phrases that will be key to your project on a search engine like google scholar, and aim for pieces of work which have been cited several times. I give more details on this under (8) below.

7. How can I measure my progress?

I like to think about scheduling this writing project by working backwards from the final deadline. So, assuming that your final draft is due for submission in March and that we can't discuss your writing any further at that stage, you should (3) plan to have a penultimate rough draft completed by the start of February. It's important to give yourself a month for revising, as your project will have matured significantly and you'll need time to rework and rewrite earlier materials, possibly quite radically. This means that (2) Dec-Jan should involve some serious writing, potentially 8-12k words (or 5-6k if you're doign the shorter dissertation). To varying degrees, (1) you might want to think of the first 2 months of dissertation work (Sep/Oct-Nov) as exploratory. You will be focussing much of your time on reading and taking notes, writing literature survey, book precis, and outlines of your project, and thinking through your methodology. If you prefer to take the writing more slowly, or work in a more compartmentalised way, i.e. researching for and writing each chapter at a time, we can do that too, so you'd finish a chapter each month starting in October, and then have February for revising. The downside of this approach is that you may need to rewrite one or more of those early chapters as your thinking develops and matures over the length of the project. Some people also like to do preliminary research over the preceding Spring and Summer - this is a good idea if you want to take the writing more slowly and work over your ideas, and also if you need to do data collection for your project.

Ultimately, it is up to you to choose a schedule for your project, so think hard about your personality and how you've worked best on long projects (not even necessarily writing ones) in the past.

8. How do I find books and articles for my dissertation?

In this age of social media and digital archives, you'll be working primarily with search engines. However, it's important to do "smart searching" which relates both to what key words and phrases you search for as well as how you use the technology. Finding the right "key words" and phrases is an art, and one which you will get better at with time. So you should practice running phrases and words through searches to see what comes up. I recommend working with Google Scholar to begin with, and then you can work with more tailored tools, like the University library findit@bham search engine. 

Here's an example of how I use this tool to run a literature search. A good search in google scholar should return less than 100 items. So, for example, typing in the words "just war" on google scholar returns over 4 million items. This is the definition of a terrible search. One search trick which will help significantly here is to treat just war as a phrase, so put it in double quotation marks for the search engine. The difference here is that you won't just get every item which is about "just" or "war" but only those things which are about `"just war"`. Big difference - now you've got just under 100k items, which means that it's getting a bit better, but still unusuable. It's good to work with contemporary literature to begin with, so try limiting the search to items written in the last decade. Just click on "custom range" on the sidebar and type in 2010 to the first box and click search. Now we're down to 19k items. Getting better. Another way to identify important articles is to notice how many times they are cited. If something has been cited more than 100 times, that is, quoted in another book or article, that's a good rule of thumb for something being generally applicable. So you might want to scan quickly for items with high citation counts before refining your list further.

A few other ideas for reducing your searchers to manageable lengths:

You can add some more keywords as well alongside "just war". So if, for example, we add "land mines" to the search (make sure this is also in double quotes as a phrase!) we're down to just 580 results. You can get through a list this long in an hour if you're just scanning the summaries and titles. So this is something you can work with. 

You might also think about limiting your search to items that have your key words only in the title. To do this in google scholar, just add the word intitle: before your search, so it looks like this:

`intitle:"just war"`

Throughout this process, you should be noting down things that seem possibly relevant to your research. Now rinse and repeat - start a new search with a different starting point. You get the idea.

9. How can I tell what mark my dissertation will get?

This is a hard question. My primary interest in the dissertation process, to the frustration of some supervisees is generally oriented around the quality of the work. This can lead to a range of very different outcomes depending on how mature your thinking is on a given topic and how much time you've invested along the way. So I'm going to tell you quite honestly if I don't think you're working up to your own standards, but I can't set a benchmark mid-way through your project. In almost every case, your thinking will mature and develop on your topic right up to the point of submission, so quite a lot hinges on leaving time for and investing in final revision of your thesis. Until we get to the final product, I can only assess how a given chapter or intellectual exploration is doing, and there's no way of knowing how this will predict the whole product. If you really want to get some kind of benchmark for your writing, you can review the bank of assessed work on canvas to see some samples of other dissertations. However, at this point in your scholarly career, I'd suggest that you intrinsically are the best measure of your progress. You will know how much effort has led in past writing to certain outcomes, and should be able to judge your work on the thesis against these past outcomes. If you're anxious about the mark, my primary advice to you is to pace yourself. Make sure that you have time at the end to revise well, and make sure that you devote time at the beginning to adequately researching your topic. A good thesis is a blend of eloquence and scholarly knowledge.

10. Anything else?

I expect we'll work through all kinds of other items in supervision and am excited to see how your project is developing!
